@@ -56,10 +56,6 @@ extern "C" {
 	void Rhcluster(const float * distMat, const int * numPoints, 
 		int * merge, int * order, float * val, const char ** method);
 
-  void RgpuMatMult(int *tpA, int *tpB, float * a, int * rowsa, int * colsa, 
-		float * b, int * rowsb, int * colsb, float * result);
-
-
 	void RgetQRDecomp(int * rows, int * cols, float * a, float * q, int * pivot,
 		int * rank);
 	void RqrSolver(int * rows, int * cols, float * matX, float * vectY, 
